Crate scadman

A library for generating OpenSCAD code.

Modules

prelude
import prelude::* so you can be ready to code!
scad_2d
2D objects in SCAD.
scad_3d
3D objects in SCAD.
scad_display
Trait and types that can be represented as a string in SCAD.
scad_mixed
Mixed objects in SCAD.
scad_sentence
Sentences in SCAD.
value_type
Types used to represent values in the library.

Structs

ScadObject
Struct representing a Scad Object

Enums

ScadObjectBody
Enum representing the body of a Scad Object.
ScadObjectDimensionType
Enum representing the dimension type of a Scad Object.

Constants

INDENT
The number of space for indent

Traits

ScadBuildable
Trait for scad objects that can be built from builder, then can be become into a ScadObject2D or ScadObject3D.
ScadBuilder
Trait for builders that can be build ScadBuildable
ScadObjectTrait
Trait for SCAD Objects

Functions

block_2d
Creates a 2D block ScadObject from a slice of ScadObjects.
block_2d_commented
Creates a 2D block ScadObject from a slice of ScadObjects with a comment.
block_3d
Creates a 3D block ScadObject from a slice of ScadObjects.
block_3d_commented
Creates a 3D block ScadObject from a slice of ScadObjects with a comment.
block_mixed
Creates a Mixed block ScadObject from a slice of ScadObjects.
block_mixed_commented
Creates a Mixed block ScadObject from a slice of ScadObjects with a comment.
modifier_2d
Creates a 2D modifier ScadObject with a child object.
modifier_2d_commented
Creates a 2D modifier ScadObject with a child object and a comment.
modifier_3d
Creates a 3D modifier ScadObject with a child object.
modifier_3d_commented
Creates a 3D modifier ScadObject with a child object and a comment.
modifier_mixed
Creates a Mixed modifier ScadObject with a child object.
modifier_mixed_commented
Creates a Mixed modifier ScadObject with a child object and a comment.
primitive_2d
Creates a 2D primitive ScadObject from the given input.
primitive_2d_commented
Creates a 2D primitive ScadObject with a comment.
primitive_3d
Creates a 3D primitive ScadObject from the given input.
primitive_3d_commented
Creates a 3D primitive ScadObject with a comment.
try_block_2d
Attempts to create a 2D block ScadObject from a slice of ScadObjects.
try_block_2d_commented
Attempts to create a 2D block ScadObject from a slice of ScadObjects with a comment.
try_block_3d
Attempts to create a 3D block ScadObject from a slice of ScadObjects.
try_block_3d_commented
Attempts to create a 3D block ScadObject from a slice of ScadObjects with a comment.
try_modifier_2d
Attempts to create a 2D modifier ScadObject with a child object.
try_modifier_2d_commented
Attempts to create a 2D modifier ScadObject with a child object and a comment.
try_modifier_3d
Attempts to create a 3D modifier ScadObject with a child object.
try_modifier_3d_commented
Attempts to create a 3D modifier ScadObject with a child object and a comment.

Type Aliases

AffineMatrix2D
Data type for Affine transformations in 2D.
AffineMatrix3D
Data type for Affine transformations in 3D.
Container2D
Container type for 2D things.
Container3D
Container type for 3D things.
Point2D
Data type for 2D points.
Point3D
Data type for 3D points.
Unit
Unit of length to write in SCAD code.