A library for generating OpenSCAD code.
Modules
- prelude
- import
prelude::*so you can be ready to code! - scad_2d
- 2D objects in SCAD.
- scad_3d
- 3D objects in SCAD.
- scad_
display - Trait and types that can be represented as a string in SCAD.
- scad_
mixed - Mixed objects in SCAD.
- scad_
sentence - Sentences in SCAD.
- value_
type - Types used to represent values in the library.
Structs
- Scad
Object - Struct representing a Scad Object
Enums
- Scad
Object Body - Enum representing the body of a Scad Object.
- Scad
Object Dimension Type - Enum representing the dimension type of a Scad Object.
Constants
- INDENT
- The number of space for indent
Traits
- Scad
Buildable - Trait for scad objects that can be built from builder,
then can be become into a
ScadObject2DorScadObject3D. - Scad
Builder - Trait for builders that can be build
ScadBuildable - Scad
Object Trait - Trait for SCAD Objects
Functions
- block_
2d - Creates a 2D block
ScadObjectfrom a slice ofScadObjects. - block_
2d_ commented - Creates a 2D block
ScadObjectfrom a slice ofScadObjects with a comment. - block_
3d - Creates a 3D block
ScadObjectfrom a slice ofScadObjects. - block_
3d_ commented - Creates a 3D block
ScadObjectfrom a slice ofScadObjects with a comment. - block_
mixed - Creates a Mixed block
ScadObjectfrom a slice ofScadObjects. - block_
mixed_ commented - Creates a Mixed block
ScadObjectfrom a slice ofScadObjects with a comment. - modifier_
2d - Creates a 2D modifier
ScadObjectwith a child object. - modifier_
2d_ commented - Creates a 2D modifier
ScadObjectwith a child object and a comment. - modifier_
3d - Creates a 3D modifier
ScadObjectwith a child object. - modifier_
3d_ commented - Creates a 3D modifier
ScadObjectwith a child object and a comment. - modifier_
mixed - Creates a Mixed modifier
ScadObjectwith a child object. - modifier_
mixed_ commented - Creates a Mixed modifier
ScadObjectwith a child object and a comment. - primitive_
2d - Creates a 2D primitive
ScadObjectfrom the given input. - primitive_
2d_ commented - Creates a 2D primitive
ScadObjectwith a comment. - primitive_
3d - Creates a 3D primitive
ScadObjectfrom the given input. - primitive_
3d_ commented - Creates a 3D primitive
ScadObjectwith a comment. - try_
block_ 2d - Attempts to create a 2D block
ScadObjectfrom a slice ofScadObjects. - try_
block_ 2d_ commented - Attempts to create a 2D block
ScadObjectfrom a slice ofScadObjects with a comment. - try_
block_ 3d - Attempts to create a 3D block
ScadObjectfrom a slice ofScadObjects. - try_
block_ 3d_ commented - Attempts to create a 3D block
ScadObjectfrom a slice ofScadObjects with a comment. - try_
modifier_ 2d - Attempts to create a 2D modifier
ScadObjectwith a child object. - try_
modifier_ 2d_ commented - Attempts to create a 2D modifier
ScadObjectwith a child object and a comment. - try_
modifier_ 3d - Attempts to create a 3D modifier
ScadObjectwith a child object. - try_
modifier_ 3d_ commented - Attempts to create a 3D modifier
ScadObjectwith a child object and a comment.
Type Aliases
- Affine
Matrix2D - Data type for Affine transformations in 2D.
- Affine
Matrix3D - Data type for Affine transformations in 3D.
- Container2D
- Container type for 2D things.
- Container3D
- Container type for 3D things.
- Point2D
- Data type for 2D points.
- Point3D
- Data type for 3D points.
- Unit
- Unit of length to write in SCAD code.